Constructs non-transformed and transformed (if the transformation \(g\) is specified) Wald confidence intervals (CIs) for estimands in contingency tables subject to equality constraints.
Wald_trans.Wald_robust(y, strata, fixed.strata, h0.fct, h0.fct.deriv,
S0.fct, S0.fct.deriv, max.mph.iter, step,
change.step.after, y.eps, iter.orig, norm.diff.conv,
norm.score.conv, max.score.diff.iter, cut.off,
S.space.H0, trans.g, trans.g.deriv, trans.g.inv,
adj.epsilon, iter.robust.max, iter.robust.eff)Observed table counts in the contingency table(s), in vector form.
Vector of the same length as y that gives the stratum
membership identifier.
The object that gives information on which stratum (strata) has (have) fixed sample sizes.
The constraint function \(h_{0}(\cdot)\) with respect to \(m\), where \(m = E(Y)\), the vector of expected table counts.
The R function object that computes analytic derivative of the
transpose of the constraint function \(h_{0}(\cdot)\) with respect to
\(m\). If h0.fct.deriv is not specified or
h0.fct.deriv = NULL, numerical derivatives will be used.
The estimand function \(S_{0}(\cdot)\) with respect to \(m\).
The R function object that computes analytic derivative of
the estimand function \(S_{0}(\cdot)\) with
respect to \(m\). If S0.fct.deriv is not
specified or S0.fct.deriv = NULL, numerical derivatives
will be used.
The parameters used in mph.fit.
qchisq(cc, 1). i.e. The chi-square cutoff, with \(1\)
df, based on the significance level 1-cc.
Restricted estimand space of \(S(\cdot)\) under \(H_{0}\), i.e. subject to the imposed equality constraints along with sampling constraints.
The transformation \(g\) used in the transformed Wald confidence interval.
The derivative function of the transformation \(g\), i.e. \(d g(w) / d w\). If it is specified, it should be an R function, even if the derivative function is a constant function.
\(g^{-1}\) function used in back-transformation step in construction of the transformed Wald confidence interval.
The parameters used in the robustifying procedure.
Wald_trans.Wald_robust returns a list, which includes two objects. The first object is
either a \(1\)-by-\(2\) matrix which displays two endpoints of the non-transformed Wald confidence interval, if the transformation \(g\) is not specified;
or a \(2\)-by-\(2\) matrix, whose first row displays two endpoints of the non-transformed Wald confidence interval, and whose second row displays two endpoints of the transformed Wald confidence interval, if the transformation \(g\) is specified.
For the second object, it includes the warning message that occurs during construction of the confidence
interval(s) if the robustifying procedure is evoked: "Wald.CI: Adjustment used. Not on original data.\n", or "Wald.CI and trans.Wald.CI: Adjustment used. Not on original data.\n". If the robustifying procedure is not evoked, the second object is NULL.
Zhu, Q. (2020) "On improved confidence intervals for parameters of discrete distributions." PhD dissertation, University of Iowa.